==> haskell-src-meta-0.8.2-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.8.2
id: haskell-src-meta-0.8.2-L1oODBLrG4O2KB6sCPs5NT
key: haskell-src-meta-0.8.2-L1oODBLrG4O2KB6sCPs5NT
license: BSD-3-Clause
copyright: (c) Matt Morrow
maintainer: danburton.email@gmail.com
author: Matt Morrow
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
abi: 69f9cef765c1451f2e90774734b22d06
exposed: True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Syntax.Translate Language.Haskell.Meta.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-meta-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-meta-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/haskell-src-meta-0.8.2
hs-libraries: HShaskell-src-meta-0.8.2-L1oODBLrG4O2KB6sCPs5NT
depends:
    base-4.12.0.0 haskell-src-exts-1.21.1-Gvt9SHsLQpU56VysZS6eS3
    pretty-1.1.3.6 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    template-haskell-2.14.0.0 th-orphans-0.13.9-3SCyNTxjlr9FB4Fil8N4LD
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.8.2-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.8.2
id: haskell-src-meta-0.8.2-7EmsfsL8inIHfRBrK0OjDI
key: haskell-src-meta-0.8.2-7EmsfsL8inIHfRBrK0OjDI
license: BSD-3-Clause
copyright: (c) Matt Morrow
maintainer: danburton.email@gmail.com
author: Matt Morrow
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
abi: 50c6c57f29202671e6dc87099f9c0859
exposed: True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Syntax.Translate Language.Haskell.Meta.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-meta-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-meta-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/haskell-src-meta-0.8.2
hs-libraries: HShaskell-src-meta-0.8.2-7EmsfsL8inIHfRBrK0OjDI
depends:
    base-4.12.0.0 haskell-src-exts-1.21.1-Knj2Sf32FhF4mJrXgorIEK
    pretty-1.1.3.6 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    template-haskell-2.14.0.0 th-orphans-0.13.9-dA6GVRFWI83WWwe8ma3Un
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
